kaybee
======

.. image:: https://img.shields.io/travis/pauleveritt/kaybee.svg
    :target: https://pypi.python.org/pypi/kaybee

.. image:: https://img.shields.io/pypi/v/kaybee.svg
    :target: https://pypi.python.org/pypi/kaybee

.. image:: https://img.shields.io/pypi/l/kaybee.svg
    :target: https://pypi.python.org/pypi/kaybee

.. image:: https://img.shields.io/pypi/pyversions/kaybee.svg
    :target: https://pypi.python.org/pypi/kaybee

Knowledge Base (KB, kaybee) using on Sphinx with schema-driven resource
directives in YAML.

See ``docs`` for details.

**Note: This package requires Python 3.6+**
